ConflictResolution class
Constructors
-
ConflictResolution({required String syncItemId, required ConflictResolutionStrategy strategy, Map<
String, dynamic> ? resolvedData, required DateTime resolvedAt}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- resolvedAt → DateTime
-
final
-
resolvedData
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strategy → ConflictResolutionStrategy
-
final
- syncItemId → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited